pub struct Error { /* private fields */ }Expand description
The Errors that may occur when processing a Request.
Implementations
Sourceimpl Error
impl Error
Sourcepub fn url(&self) -> Option<&Url>
pub fn url(&self) -> Option<&Url>
Returns a possible URL related to this error.
Examples
// displays last stop of a redirect loop
let response = reqwest::get("http://site.with.redirect.loop").await;
if let Err(e) = response {
if e.is_redirect() {
if let Some(final_stop) = e.url() {
println!("redirect loop at {}", final_stop);
}
}
}Sourcepub fn is_builder(&self) -> bool
pub fn is_builder(&self) -> bool
Returns true if the error is from a type Builder.
Sourcepub fn is_redirect(&self) -> bool
pub fn is_redirect(&self) -> bool
Returns true if the error is from a RedirectPolicy.
Sourcepub fn is_timeout(&self) -> bool
pub fn is_timeout(&self) -> bool
Returns true if the error is related to a timeout.
Sourcepub fn is_request(&self) -> bool
pub fn is_request(&self) -> bool
Returns true if the error is related to the request
Sourcepub fn is_connect(&self) -> bool
pub fn is_connect(&self) -> bool
Returns true if the error is related to connect
Sourcepub fn is_body(&self) -> bool
pub fn is_body(&self) -> bool
Returns true if the error is related to the request or response body
Sourcepub fn is_decode(&self) -> bool
pub fn is_decode(&self) -> bool
Returns true if the error is related to decoding the response’s body
Sourcepub fn status(&self) -> Option<StatusCode>
pub fn status(&self) -> Option<StatusCode>
Returns the status code, if the error was generated from a response.